## Topsis
TOPSIS is an acronym that stands for 'Technique of Order Preference Similarity to the Ideal Solution' and is a pretty straightforward MCDA method.

# How to use this package

```
$ pip install topsis-Aman-101803543

$ python

>>> from topsis_aman import topsisf
>>> topsisf(["filename.csv","weights","impact","resultFile.csv"])


then it shows your answer on command prompt and save it as a file
```
